arrc.models.embeddings.resnet
=============================

.. automodule:: arrc.models.embeddings.resnet

   
   .. rubric:: Functions

   .. autosummary::
   
      build_resnet_cnn_model
      res_block
   